Credits
-------

This utility was created at `DealerTrack Technologies`_
(`DealerTrack GitHub`_) for our internal use so thank you
DealerTrack for allowing to contribute the utility
to the open-source community.

Development Lead
~~~~~~~~~~~~~~~~

* Miroslav Shubernetskiy - https://github.com/miki725

Contributors
~~~~~~~~~~~~

* Ben Homnick - https://github.com/bhomnick


.. _DealerTrack GitHub: https://github.com/Dealertrack
.. _DealerTrack Technologies: https://www.dealertrack.com
